@@ -36,7 +36,7 @@ private:
     QUrl urllogin;
     QUrl urldologin;
     QUrl urlupdate;
-    qint64 lastupdate;
+    unsigned int lastupdate;
     bool login_error;
 };
 
