@@ -123,8 +123,8 @@ void LatitudeGUI::mode_demonio() {
         demonio->setText(tr("&Start Daemon"));
     } else {
         QProcess *cli = new QProcess(this);
-        cli->start(QCoreApplication::applicationDirPath()+"/GoogleLatitudeDaemon");
-        qDebug() << "LatitudeGUI: demonio " << QCoreApplication::applicationDirPath()+"/GoogleLatitudeDaemon";
+        cli->start(QCoreApplication::applicationDirPath()+QDir::separator()+"GoogleLatitudeDaemon");
+        qDebug() << "LatitudeGUI: demonio" << QCoreApplication::applicationDirPath()+"/GoogleLatitudeDaemon";
         if ( ! system("killall -0 GoogleLatitudeDaemon 2> /dev/null" ) ) {
             demonio->setText(tr("&Stop Daemon"));
         }
